@@ -30,8 +30,10 @@ class MergePR:
 
         pr = self._select_pr()
 
-        print(f"\nHai selezionato: \n{self._check_pr_status(pr)}")
-        if not prompt_utils.ask_confirm("Vuoi continuare il merge?", default=False):
+        print(f"\nYou have selected: \n{self._check_pr_status(pr)}")
+        if not prompt_utils.ask_confirm(
+            "Do you want to continue the merge?", default=False
+        ):
             sys.exit()
 
         branch_name = pr.head.ref
@@ -39,7 +41,7 @@ class MergePR:
 
         _check_migrations_merge(pr)
 
-        logger.info("Eseguo il merge...")
+        logger.info("Merging...")
 
         merge_status = pr.merge(
             commit_title=f"{pr.title} (#{pr.number})",
@@ -48,7 +50,7 @@ class MergePR:
         )
 
         if not merge_status.merged:
-            logger.error("Si è verificato un errore durante il merge.")
+            logger.error("An error occurred during the merge.")
             sys.exit(-1)
 
         drone_build_number = self._drone.get_pr_build_number(merge_status.sha)
@@ -56,51 +58,51 @@ class MergePR:
 
         if drone_build_url:
             logger.info(
-                f"Pull request mergiata su master! Puoi seguire lo stato della build su {drone_build_url}"
+                f"Pull request merged on master! You can follow the build status at {drone_build_url}"
             )
         else:
-            logger.info("Pull request mergiata su master!")
+            logger.info("Pull request merged on master!")
 
         self._git.fetch()
         if self._git.remote_branch_exists(branch_name):
             self._git.delete_remote_branch(branch_name)
 
         if prompt_utils.ask_confirm(
-            "Vuoi bloccare staging? (Necessario se bisogna testare su staging)",
+            "Do you want to lock staging? (If you need to test on staging)",
             default=False,
         ):
             if self._drone.prestart_success(drone_build_number):
                 self._captainhook.lock_project(self._project, "staging")
             else:
                 logger.error(
-                    "Problemi con la build su drone, non riesco a bloccare staging"
+                    "There were problems with the drone build, can't lock staging"
                 )
                 sys.exit(-1)
 
         if youtrack_id:
-            logger.info("Aggiorno lo stato della card su youtrack...")
+            logger.info("Updating card status on YouTrack...")
             self._youtrack.update_state(
                 youtrack_id, self._config.youtrack["merged_state"]
             )
-            logger.info("Card aggiornata")
+            logger.info("Card updated")
 
-            logger.info("Spengo il qa, se esiste")
+            logger.info("Turning off the QA, if it exists")
             qainit_shutdown(youtrack_id, self._config)
         else:
             logger.warning(
-                "Non sono riuscito a trovare una issue YouTrack nel nome del branch o la issue indicata non esiste."
+                "There is no YouTrack issue in the branch name or the selected issue does not exist."
             )
             logger.warning(
-                "Nessuna card aggiornata su YouTrack e nessun QA spento in automatico"
+                "No card updated on YouTrack and no QA turned off automatically"
             )
 
-        logger.info("Tutto fatto!")
+        logger.info("All done!")
         sys.exit()
 
     def _select_pr(self):
         if self._github.user_is_admin(self._project):
             logger.warning(
-                "Sei admin del repository, puoi fare il merge skippando i check (CI, review, ecc...)\nDa grandi poteri derivano grandi responsabilita'"
+                "You are admin of the repository, you can merge it skipping the checks (CI, review, etc ...)\nWith great power comes great responsibility"
             )
 
         with Halo(text="Loading pull requests...", spinner="dots", color="magenta"):
@@ -110,10 +112,10 @@ class MergePR:
             ]
         if choices:
             choices.sort(key=lambda x: x["name"])
-            return prompt_utils.ask_choices("Seleziona PR: ", choices)
+            return prompt_utils.ask_choices("Select PR: ", choices)
 
         logger.error(
-            f"Non esistono pull request pronte per il merge o potresti non avere i permessi, per favore controlla su https://github.com/primait/{self._project}/pulls"
+            f"There are no pull requests ready to be merged or you may not have the permissions, please check on https://github.com/primait/{self._project}/pulls"
         )
         sys.exit(-1)
 
@@ -121,13 +123,13 @@ class MergePR:
         request = self._captainhook.status(self._project, "staging")
 
         if request.status_code != 200:
-            logger.error("Impossibile determinare lo stato del lock su master.")
+            logger.error("Unable to determine lock status on master.")
             sys.exit(-1)
 
         request_object = request.json()
         if request_object["locked"]:
             logger.error(
-                f"Il progetto è lockato su staging da {request_object['by']}. Impossibile continuare."
+                f"The project is locked on staging by {request_object ['by']}. Unable to continue."
             )
             sys.exit(-1)
 
@@ -137,7 +139,7 @@ class MergePR:
         print(pr.mergeable_state)
         if pr.mergeable_state == "dirty":
             logger.error(
-                "La pull request selezionata non è mergeable. Controlla se ci sono conflitti."
+                "The selected pull request is not mergeable. Check for conflicts."
             )
             sys.exit(-1)
         if pr.mergeable_state == "blocked":
@@ -155,8 +157,8 @@ class MergePR:
 def _check_migrations_merge(pr):
     files_changed = [x.filename for x in pr.get_files()]
     if git.migrations_found(files_changed):
-        logger.warning("ATTENZIONE: migrations rilevate nel codice")
-        if not prompt_utils.ask_confirm("Sicuro di voler continuare?"):
+        logger.warning("WARNING: migrations detected in the code")
+        if not prompt_utils.ask_confirm("Are you sure you want to continue?"):
             sys.exit()
 
 
