@@ -48,7 +48,8 @@ class GitHandler:
                     stdout=subprocess.DEVNULL,
                     stderr=subprocess.DEVNULL,
                 )
-                self.pull(rebase=True)
+                if not self.is_detached():  # Skip pulling if detached
+                    self.pull(rebase=True)
         except (CalledProcessError) as e:
             logger.error(f"Error during command execution: {e}")
             sys.exit(-1)
@@ -214,6 +215,9 @@ class GitHandler:
             logger.error(f"Error during command execution: {e}")
             sys.exit(-1)
 
+    def is_detached(self):
+        return self.current_branch_name() == "HEAD"
+
     def is_dirty(self, untracked=False):
         if untracked:
             command = ["git", "status", "--porcelain"]
