@@ -2,6 +2,10 @@
 from termcolor import colored
 
 
+def debug(message):
+    print(colored(message, "blue"))
+
+
 def info(message):
     print(colored(message, "green"))
 
